@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -354,7 +354,7 @@ public class CurrencyNames_et extends OpenListResourceBundle {
             { "mcf", "Monaco frank" },
             { "mdl", "Moldova leu" },
             { "mga", "Madagaskari ariari" },
-            { "mgf", "Madagaskar frank" },
+            { "mgf", "Madagaskari frank" },
             { "mkd", "Makedoonia dinaar" },
             { "mkn", "Makedoonia dinaar (1992\u20131993)" },
             { "mlf", "Mali frank" },
