@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -122,6 +122,14 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
                "heure de l\u2019Iran",
                "",
             };
+        final String[] Niue = new String[] {
+               "heure de Niou\u00e9",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Omsk = new String[] {
                "heure normale d\u2019Omsk",
                "",
@@ -218,6 +226,14 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
                "heure des A\u00e7ores",
                "",
             };
+        final String[] Brunei = new String[] {
+               "heure du Brun\u00e9i",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Easter = new String[] {
                "heure normale de l\u2019\u00eele de P\u00e2ques",
                "",
@@ -266,14 +282,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
                "heure de l\u2019Arm\u00e9nie",
                "",
             };
-        final String[] ETC_UTC = new String[] {
-               "temps universel coordonn\u00e9",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Georgia = new String[] {
                "heure normale de la G\u00e9orgie",
                "",
@@ -482,6 +490,14 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
                "heure du Cap-Vert",
                "",
             };
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Uzbekistan = new String[] {
                "heure normale de l\u2019Ouzb\u00e9kistan",
                "",
@@ -755,7 +771,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC", ETC_UTC },
+            { "UTC", EMPTY_ZONE },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
             { "ART", Europe_Eastern },
@@ -778,7 +794,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "PST", America_Pacific },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
-            { "Etc/UTC", ETC_UTC },
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
             { "Asia/Aden", Arabian },
@@ -786,7 +801,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
             { "Asia/Macau", China },
@@ -795,6 +809,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Africa/Juba", Africa_Central },
             { "Asia/Anadyr", Anadyr },
             { "Asia/Beirut", Europe_Eastern },
+            { "Asia/Brunei", Brunei },
             { "Asia/Harbin", China },
             { "Asia/Hebron", Europe_Eastern },
             { "Asia/Kuwait", Arabian },
@@ -828,6 +843,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Europe/Vaduz", Europe_Central },
             { "Pacific/Apia", Apia },
             { "Pacific/Fiji", Fiji },
+            { "Pacific/Niue", Niue },
             { "SystemV/AST4", Atlantic },
             { "SystemV/CST6", America_Central },
             { "SystemV/EST5", America_Eastern },
@@ -850,7 +866,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Jujuy", Argentina },
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
@@ -901,7 +916,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Mountain },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
             { "America/Juneau", Alaska },
@@ -959,7 +973,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1030,7 +1044,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1065,7 +1079,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
@@ -1100,6 +1113,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Scoresbysund", Greenland_Eastern },
             { "Antarctica/Macquarie", Australia_Eastern },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1127,6 +1141,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Asia/Thimphu", "Thimphou" },
+            { "timezone.excity.Pacific/Palau", "Palau" },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Africa/Tripoli", "Tripoli [Libye]" },
@@ -1140,6 +1155,8 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "timezone.excity.America/St_Kitts", "Saint-Christophe-et-Ni\u00e9v\u00e8s" },
             { "timezone.excity.America/St_Thomas", "Saint Thomas" },
             { "timezone.excity.Europe/Isle_of_Man", "\u00eele de Man" },
+            { "timezone.excity.America/Tegucigalpa", "T\u00e9gucigalpa" },
+            { "timezone.excity.Antarctica/DumontDUrville", "Dumont d\u2019Urville" },
             { "timezone.excity.America/North_Dakota/Beulah", "Beulah [Dakota du Nord]" },
             { "timezone.excity.America/North_Dakota/Center", "Center [Dakota du Nord]" },
             { "timezone.excity.America/North_Dakota/New_Salem", "New Salem, Dakota du Nord" },
